ExpandableCarouselControllerImpl class
Implementation of the ExpandableCarouselController interface.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onReady
→ Future<
void> -
Future that completes when the controller is ready.
no setteroverride
- ready → bool
-
Checks if the controller is ready to interact with the carousel.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ← ExpandableCarouselState?
-
Sets the current state of the carousel.
no getter
Methods
-
animateToPage(
int page, {Duration? duration = const Duration(milliseconds: 300), Curve? curve = Curves.linear}) → void -
Animates the controlled ExpandableCarousel from the current page to the given page.
The animation lasts for the given duration and follows the given curve.
The returned Future resolves when the animation completes.
override
-
jumpToPage(
int page) → void -
Changes which page is displayed in the controlled ExpandableCarousel.
Jumps the page position from its current value to the given value,
without animation, and without checking if the new value is in range.
override
-
nextPage(
{Duration? duration = const Duration(milliseconds: 300), Curve? curve = Curves.linear}) → void -
Animates the controlled ExpandableCarousel to the next page.
The animation lasts for the given duration and follows the given curve.
The returned Future resolves when the animation completes.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
previousPage(
{Duration? duration = const Duration(milliseconds: 300), Curve? curve = Curves.linear}) → void -
Animates the controlled ExpandableCarousel to the previous page.
The animation lasts for the given duration and follows the given curve.
The returned Future resolves when the animation completes.
override
-
startAutoPlay(
) → void -
Starts the controlled ExpandableCarousel autoplay.
The carousel will only autoPlay if the
autoPlayparameter in ExpandableCarouselOptions is true.override -
stopAutoPlay(
) → void -
Stops the controlled ExpandableCarousel from autoplaying.
This is a more on-demand way of doing this. Use the
autoPlayparameter in ExpandableCarouselOptions to specify the autoPlay behaviour of the carousel.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited