FlutterCarousel class

Main carousel widget There are two constructors - one for direct list of items and another for builder pattern (itemBuilder). The options parameter controls various carousel behaviors such as auto-play, scroll direction, etc.

Inheritance

Constructors

FlutterCarousel({required List<Widget>? items, required FlutterCarouselOptions options, Key? key})
The default constructor
const
FlutterCarousel.builder({required int? itemCount, required ExtendedWidgetBuilder? itemBuilder, required FlutterCarouselOptions options, Key? key})
Constructor for on-demand item builder pattern
const

Properties

hashCode int
The hash code for this object.
no setterinherited
itemBuilder → ExtendedWidgetBuilder?
Widget item builder that builds items on-demand
final
itemCount int?
The count of items to be shown in the carousel
final
items List<Widget>?
List of widgets to be shown in the carousel for the default constructor
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
options FlutterCarouselOptions
Configuration options for the carousel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _FlutterCarouselState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited